<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://sendapp.live
 * @since      1.0.0
 *
 * @package    Xc_Woo_Sendapp
 * @subpackage Xc_Woo_Sendapp/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Xc_Woo_Sendapp
 * @subpackage Xc_Woo_Sendapp/admin
 * @author     SendApp <info@sendapp.live>
 */
class Xc_Woo_Sendapp_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		add_action('init', array($this, 'init'));

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wp-woo-notify-admin.css', array(), $this->version, 'all' );
		

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wp-woo-notify-admin.js', array( 'jquery' ), $this->version, false );
		wp_localize_script( $this->plugin_name, "xc_woo_sendapp",
            array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );

	}
	
	public function init(){
		$message_type = get_option("xc_woo_sendapp_default_type");
		if($message_type){
			if('sms' == $message_type){
				update_option('xc_woo_sendapp_send_sms', 'yes');	
			}
			if('whatsapp' == $message_type){
				update_option('xc_woo_sendapp_send_whatsapp', 'yes');	
			}
			delete_option("xc_woo_sendapp_default_type");
		}
	}
	
	
	public function output_sections() {
		global $current_section;

		$sections = $this->get_sections();

		if ( empty( $sections ) || 1 === sizeof( $sections ) ) {
			return;
		}

		echo '<ul class="subsubsub">';

		$array_keys = array_keys( $sections );

		foreach ( $sections as $id => $label ) {
			echo '<li><a href="' . admin_url( 'admin.php?page=wc-settings&tab=xc_woo_sendapp&section=' . sanitize_title( $id ) ) . '" class="' . ( $current_section == $id ? 'current' : '' ) . '">' . $label . '</a> ' . ( end( $array_keys ) == $id ? '' : '|' ) . ' </li>';
		}

		echo '</ul><br class="clear" />';
	}
	
	
	public function get_sections() {
		$sections = array(
			'' => __( 'SendApp API Settings', 'wp-woo-notify' ),
			'messages' => __( 'Messages Configuration', 'wp-woo-notify' ),
			'guide' => __( 'Guide', 'wp-woo-notify' ),
		);
		
		
		return $sections;
	}
	
	
	
	
	/**
     * Add a new settings tab to the WooCommerce settings tabs array.
     *
     * @param array $settings_tabs Array of WooCommerce setting tabs & their labels, excluding the Subscription tab.
     * @return array $settings_tabs Array of WooCommerce setting tabs & their labels, including the Subscription tab.
	 * @since    1.0.0
     */
    public static function add_settings_tab( $settings_tabs ) {
        $settings_tabs['xc_woo_sendapp'] = __( 'Sendapp SMS/WhatsApp Notifications', 'wp-woo-notify' );
        return $settings_tabs;
    }
	
	
	/**
     * Uses the WooCommerce admin fields API to output settings via the @see woocommerce_admin_fields() function.
     *
     * @uses woocommerce_admin_fields()
     * @uses self::get_settings()
     */
    public static function settings_tab() {
		global $current_section;
		if($current_section=='guide'){
			?>
			<iframe src="https://sendapp.live/en/wordpress-woocommerce-sms-and-whatsapp-notifications/" width="100%" height="600" style="border:none;">
</iframe>
<?php
	return ;
		}
        woocommerce_admin_fields( Xc_Woo_Sendapp_Admin::get_settings( $current_section ) );
    }
	
	/**
     * Uses the WooCommerce options API to save settings via the @see woocommerce_update_options() function.
     *
     * @uses woocommerce_update_options()
     * @uses self::get_settings()
     */
    public static function update_settings() {
		global $current_section;
        woocommerce_update_options( Xc_Woo_Sendapp_Admin::get_settings( $current_section ) );
    }
	
	
	/**
     * Get all the settings for this plugin for @see woocommerce_admin_fields() function.
     *
     * @return array Array of settings for @see woocommerce_admin_fields() function.
     */
    public static function get_settings( $current_section = '' ) {
		if($current_section == ''){
			$settings = array(
				'section_title' => array(
					'name'     => __( 'SendApp API Settings', 'wp-woo-notify' ),
					'type'     => 'title',
					'desc'     => '',
					'id'       => 'xc_woo_sendapp_section_title'
				),
				'_xc_woo_sendapp_sid' => array(
					'name' => __( 'SendApp Access Token', 'wp-woo-notify' ),
					'type' => 'text',
					'desc' => __( 'The Access Token for your account https://sendapp.cloud', 'wp-woo-notify' ),
					'id'   => 'xc_woo_sendapp_sid'
				),
				'_xc_woo_sendapp_token' => array(
					'name' => __( 'SendApp Istance ID', 'wp-woo-notify' ),
					'type' => 'text',
					'desc' => __('The Istance ID for your account in https://sendapp.cloud', 'wp-woo-notify' ),
					'id'   => 'xc_woo_sendapp_token'
				),
				
				'_xc_woo_sendapp_whatsapp_number' => array(
					'name' => __( 'SendApp Connect Email', 'wp-woo-notify' ),
					'type' => 'text',
					'desc' => __('The Email of SendApp Connect configuration', 'wp-woo-notify' ),
					'id'   => 'xc_woo_sendapp_whatsapp_number'
				),
				
				'_xc_woo_sendapp_sms_number' => array(
					'name' => __( 'SendApp SMS API Key', 'wp-woo-notify' ),
					'type' => 'text',
					'desc' => __('The SendApp SMS API Key of your account https://sms.sendapp.live', 'wp-woo-notify' ),
					'id'   => 'xc_woo_sendapp_sms_number'
				),
				
				
				'_xc_woo_sendapp_send_sms' => array(
					'name' => __( 'Default notification type', 'wp-woo-notify' ),
					'type' => 'checkbox',
					'checkboxgroup' => 'start',
					'desc'       => __( 'SMS', 'wp-woo-notify' ),
					'id'   => 'xc_woo_sendapp_send_sms'
				),
				'_xc_woo_sendapp_send_whatsapp' => array(
					'type' => 'checkbox',
					'checkboxgroup' => 'end',
					'desc'       => __( 'WhatsApp', 'wp-woo-notify' ),
					'id'   => 'xc_woo_sendapp_send_whatsapp'
				),
				
				
				'section_end' => array(
					 'type' => 'sectionend',
					 'id' => 'xc_woo_sendapp_section_end'
				)
			);
		}elseif($current_section == "messages"){
			$settings = array(
				array(
					'name'     => __( 'New Order Notification', 'wp-woo-notify' ),
					'type'     => 'title',
					'desc'     => __('This notification will send to admin when a new order was placed', 'wp-woo-notify' ),
					'id'       => 'xc_woo_sendapp_section_messages_start'
				),
				array(
					'name' => __( 'New Order Notification', 'wp-woo-notify' ),
					'type' => 'checkbox',
					'desc' => __( 'Enable New Order Notification', 'wp-woo-notify' ),
					'id'   => 'xc_woo_sendapp_neworder'
				),
				array(
					'name' => __( 'Message', 'wp-woo-notify' ),
					'type' => 'textarea',
					'desc' => __( 'Available placeholders: {billing_first_name} , {billing_last_name},  {order_number} , {order_total}, {site_title}', 'wp-woo-notify' ),
					'css'  => "height:100px",
					'default' => "A new order was placed by {billing_first_name}  {billing_last_name}, Order Id : {order_number} Order Amount : {order_total}",
 					'id'   => 'xc_woo_sendapp_neworder_message'
				),
				array(
					 'type' => 'sectionend',
					 'id' => 'xc_woo_sendapp_section_messages_end'
				)
			);
			
			$status = wc_get_order_statuses();
			$prefix = 'wc-';
			foreach($status as $key=>$val){
				if (substr($key, 0, strlen($prefix)) == $prefix) {
					$key = substr($key, strlen($prefix));
				}
				
				$temp  = array(
				array(
					'name'     => sprintf("%s %s", __( 'Send Notification when Order is', 'wp-woo-notify' ), $val),
					'type'     => 'title',
					'desc'     => sprintf("%s %s", __('This notification will send when a order status is changed to', 'wp-woo-notify' ),$val),
					'id'       => 'xc_woo_sendapp_section_messages_start'
				),
				array(
					'name' => __( 'Send notification to admin', 'wp-woo-notify' ),
					'type' => 'checkbox',
					'desc' => sprintf("%s %s", __( 'Send notification to admin when ouder is', 'wp-woo-notify' ), $val),
					'id'   => 'xc_woo_sendapp_admin_enable_order_status_'.$key
				),
				array(
					'name' => __( 'Admin message', 'wp-woo-notify' ),
					'type' => 'textarea',
					'desc' => __( 'Available placeholders: {order_status}, {billing_first_name} , {billing_last_name},  {order_number} , {order_total}, {site_title}', 'wp-woo-notify' ),
					'css'  => "height:100px",
					'default' => "{site_title}: status of order #{order_number} has been changed to {order_status}.",
 					'id'   => 'xc_woo_sendapp_admin_message_'.$key
				),
				array(
					'name' => __( 'Send notification to customer', 'wp-woo-notify' ),
					'type' => 'checkbox',
					'desc' => sprintf("%s %s", __( 'Send notification to customer when ouder is', 'wp-woo-notify' ), $val),
					'id'   => 'xc_woo_sendapp_customer_enable_order_status_'.$key
				),
				array(
					'name' => __( 'Customer message', 'wp-woo-notify' ),
					'type' => 'textarea',
					'desc' => __( 'Available placeholders: {order_status}, {billing_first_name} , {billing_last_name},  {order_number} , {order_total}, {site_title}', 'wp-woo-notify' ),
					'css'  => "height:100px",
					'default' => "Hello {billing_first_name}, status of your order {order_number} with {site_title} has been changed to {order_status}.",
 					'id'   => 'xc_woo_sendapp_customer_message_'.$key
				),
				array(
					 'type' => 'sectionend',
					 'id' => 'xc_woo_sendapp_section_messages_end'
				)
			);
			
			$settings = array_merge($settings,$temp);
				
			}
			
			$temp  = array(
				array(
					'name'     => __( 'Send Notification when a new note is added to order', 'wp-woo-notify' ),
					'type'     => 'title',
					'desc'     => __('This notification will send when a new note is added to order', 'wp-woo-notify' ),
					'id'       => 'xc_woo_sendapp_section_messages_start_new_note'
				),
				array(
					'name' => __( 'Send notification to customer', 'wp-woo-notify' ),
					'type' => 'checkbox',
					'desc' => __( 'Send notification to customer when a new note is added to order', 'wp-woo-notify'),
					'id'   => 'xc_woo_sendapp_customer_enable_order_note'
				),
				array(
					'name' => __( 'Customer message', 'wp-woo-notify' ),
					'type' => 'textarea',
					'desc' => __( 'Available placeholders: {order_note}, {billing_first_name} , {billing_last_name},  {order_number} , {order_total}, {site_title}', 'wp-woo-notify' ),
					'css'  => "height:100px",
					'default' => "Hello {billing_first_name}, a new note has been added to your order {order_number}: {order_note}",
 					'id'   => 'xc_woo_sendapp_customer_message_note'
				),
				array(
					 'type' => 'sectionend',
					 'id' => 'xc_woo_sendapp_section_messages_end'
				)
			);
			
			$settings = array_merge($settings,$temp);
			
			
		}
        return apply_filters( 'wc_settings_tab_xc_woo_sendapp_settings', $settings );
    }
	
	public function plugin_action_links( $links ){
		$action_links = array(
			'settings' => '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=xc_woo_sendapp' ) . '" aria-label="' . esc_attr__( 'settings', 'wp-woo-notify' ) . '">' . esc_html__( 'Settings', 'wp-woo-notify' ) . '</a>',
		);

		return array_merge( $action_links, $links );
	}
	
	public function add_order_meta_box() {

		add_meta_box('xc_woo_sendapp_order_meta_box', esc_html__( 'SMS/WhatsApp Messages', 'wp-woo-notify' ), array( $this, 'display_order_meta_box' ), 'shop_order', 'side', 'default' );
	}
	
	public function display_order_meta_box( $post ){
		?>
        <p><?php echo esc_attr__( 'Message', 'wp-woo-notify' );?></p>
        <p><textarea type="text" name="xc_woo_sendapp_order_message" id="xc_woo_sendapp_order_message" class="input-text" style="width: 100%;" rows="4"></textarea></p>
        <div class="xc_woo_sendapp_order_message_buttons">
        	<a data-order-id="<?php echo $post->ID;?>" class="button xc_woo_sendapp_order_message_buttons_load_message" href="jvascript:void(0)"><?php echo esc_attr__( 'Load Order Status Message', 'wp-woo-notify' );?></a>
            <a data-order-id="<?php echo $post->ID;?>" class="button xc_woo_sendapp_order_message_buttons_send_message button-primary" href="jvascript:void(0)"><?php echo esc_attr__( 'Send', 'wp-woo-notify' );?></a>
        </div>
        <?php
	}
	
	public function xc_woo_sendapp_order_message_load_message(){
		$order_id = $_POST['order_id'];
		$order = wc_get_order( $order_id );
		$order_status  = $order->get_status();
		$message = get_option("xc_woo_sendapp_customer_message_{$order_status}");
		wp_send_json_success(array('message' => $message));
	}
	
	public function xc_woo_sendapp_order_message_send_message(){
		$order_id = $_POST['order_id'];
		$message = $_POST['message'];
		ob_start();
		do_action('xc_woo_sendapp_custom_message', $order_id, $message);
		$message = ob_get_clean();
		wp_send_json_success(array('message' => $message));
	}

}
